chembl_compatibility
======

This is chembl_compatibility package developed at Chembl group, EMBL-EBI, Cambridge, UK.

This package provides a compatibility layer between migration and core models and database created by migration.
In simple words if you want to run your own webservices on a database created from sql dumps provided by ChEMBL or
with structure the same as the one in dumps you need to include this application is your settings file if you don't
want to manually modify webservices code.
